@@ -2,11 +2,19 @@
 # turned into default functions by setMethodS3().
 
 append <- appendVarArgs(append);
-readLines <- appendVarArgs(readLines);
+
+# USED TO DO: readLines <- appendVarArgs(readLines)
+readLines <- function(...) UseMethod("readLines");
+setMethodS3("readLines", "default", function(...) {
+  base::readLines(...);
+})
 
 
 ############################################################################
 # HISTORY:
+# 2012-03-06 [HB]
+# o CRAN POLICY: Removed all internal copies of 'base' functions that
+#   have .Internal() calls. 
 # 2007-02-27 [HB]
 # o BUG FIX: Removed explicit reference to 'base' etc again. The reason is 
 #   that if a previous package already modified, say, write(), to become a 
