@@ -117,7 +117,8 @@ setMethodS3("as.character", "GenericDataFileSetList", function(x, ...) {
   }
 
   GenericSummary(s);
-})
+}, protected=TRUE)
+
 
 setMethodS3("clone", "GenericDataFileSetList", function(this, ...) {
   res <- NextMethod("clone");
@@ -127,7 +128,7 @@ setMethodS3("clone", "GenericDataFileSetList", function(this, ...) {
   }
   res$.dsList <- dsList;
   res;
-})
+}, protected=TRUE)
 
 
 setMethodS3("getAsteriskTags", "GenericDataFileSetList", function(this, ..., collapse=",") {
@@ -151,7 +152,7 @@ setMethodS3("setTags", "GenericDataFileSetList", function(this, tags=NULL, ...)
   this$.tags <- tags;
 
   invisible(this);
-})
+}, protected=TRUE)
 
 
 setMethodS3("getTags", "GenericDataFileSetList", function(this, ...) {
@@ -176,7 +177,7 @@ setMethodS3("getDefaultFullName", "GenericDataFileSetList", function(this, colla
   fullname <- paste(c(name, tags), collapse=",");
 
   fullname;
-})
+}, protected=TRUE)
 
 
 setMethodS3("as.list", "GenericDataFileSetList", function(x, ...) {
@@ -452,42 +453,6 @@ setMethodS3("getFileList", "GenericDataFileSetList", function(this, ..., dropMis
 })
 
 
-
-setMethodS3("getFileListV0", "GenericDataFileSetList", function(this, name, dropMissing=TRUE, ...) {
-  throw("DEPRECATED");
-
-  # Argument 'name':
-  name <- Arguments$getCharacter(name);
-
-  dsList <- getSets(this);
-
-  dfList <- list();
-  names <- character(0);
-  for (kk in seq_along(dsList)) {
-    ds <- dsList[[kk]];
-    idx <- indexOf(ds, name);
-    if (!is.na(idx)) {
-      dfList[[kk]] <- getFile(ds, idx);
-      names[kk] <- names(dsList)[kk];
-    }
-  }
-  if (!is.null(names(dfList))) {
-    names(dfList) <- names;
-  }
-
-  if (dropMissing) {
-    dfList <- dfList[!sapply(dfList, FUN=is.null)];
-  }
-
-  # Coerce to a file list
-  className <- getFileListClass(this);
-  clazz <- Class$forName(className);
-  dfList <- newInstance(clazz, dfList);
-
-  dfList;
-}, deprecated=TRUE)
-
-
 ###########################################################################
 # HISTORY:
 # 2012-11-12
